@@ -243,10 +243,12 @@ class BaseForward:
                     self.epochs_data[epoch].best_params = best_params
 
                     test_strategy = self.strategy()
+                    test_strategy.tune(direction=self.direction)
                     test_strategy.run(epoch_data.df_test, best_params)
                     test_profit = test_strategy.get_profit()
 
                     train_strategy = self.strategy()
+                    train_strategy.tune(direction=self.direction)
                     train_strategy.run(epoch_data.df_train, best_params)
                     train_profit = train_strategy.get_profit()
                     train_rel_profit = train_profit * self.test_window_days / self.train_window_days
@@ -298,6 +300,7 @@ class BaseForward:
             stop *= 1000
             start = max(start, last_stop)
             strategy = self.strategy()
+            strategy.tune(direction=self.direction)
             strategy.run(self.df, epoch.best_params)
             epoch_trades = strategy.trades
             epoch_trades = epoch_trades[(epoch_trades['open_time'] >= start) & (epoch_trades['open_time'] <= stop)]
@@ -315,7 +318,7 @@ class ForwardOpt(BaseForward):
         """ Создать задачи """
         for epoch, epoch_data in self.epochs_data.copy().items():
             self.epochs_data[epoch].task = self.pool.apply_async(find_best_params_optimization, (
-                get_calc_strategy_func(self.strategy),
+                get_calc_strategy_func(self.strategy, direction=self.direction),
                 epoch_data.df_train,
                 self.param_ranges
             ))
@@ -328,7 +331,7 @@ class ForwardBrut(BaseForward):
         """ Создать задачи """
         for epoch, epoch_data in self.epochs_data.copy().items():
             self.epochs_data[epoch].task = self.pool.apply_async(find_best_params_brut, (
-                get_calc_strategy_func(self.strategy, brut=True),
+                get_calc_strategy_func(self.strategy, brut=True, direction=self.direction),
                 epoch_data.df_train,
                 self.param_ranges
             ))
@@ -341,7 +344,7 @@ class ForwardParallelBrut(BaseForward):
         """ Создать задачи """
         for epoch, epoch_data in self.epochs_data.copy().items():
             self.epochs_data[epoch].task = FakeTask(find_best_params_brut_parallel, [
-                get_calc_strategy_func(self.strategy, brut=True),
+                get_calc_strategy_func(self.strategy, brut=True, direction=self.direction),
                 epoch_data.df_train,
                 self.param_ranges
             ])
